@@ -1,6 +1,13 @@
 from django.conf import settings
 import sys
 
+
+def import_name(name):
+    components = name.split('.')
+    mod = __import__('.'.join(components[0:-1]), globals(), locals(), [components[-1]] )
+    return getattr(mod, components[-1])
+
+
 def import_backend_modules(submodule=None):
     backends = getattr(settings, 'GETPAID_BACKENDS', [])
     modules = {}
@@ -19,15 +26,19 @@ def get_backend_choices(currency=None):
     Get active backends modules. Backend list can be filtered by supporting given currency.
     """
     choices = []
-    backends = import_backend_modules()
-    if currency:
-        for backend in backends.keys():
-            if currency not in backends[backend].PaymentProcessor.BACKEND_ACCEPTED_CURRENCY:
-                del backends[backend]
-    for name, module in backends.items():
-        choices.append((name, module.PaymentProcessor.BACKEND_NAME))
+    backends_names = getattr(settings, 'GETPAID_BACKENDS', [])
+
+    for backend_name in backends_names:
+        backend = import_name(backend_name)
+        print backend
+        if currency:
+            if currency in backend.PaymentProcessor.BACKEND_ACCEPTED_CURRENCY:
+                choices.append((backend_name, backend.PaymentProcessor.BACKEND_NAME, ))
+        else:
+            choices.append((backend_name, backend.PaymentProcessor.BACKEND_NAME, ))
     return choices
 
+
 def get_backend_settings(backend):
     """
     Returns backend settings. If it does not exist it fails back to empty dict().
