@@ -1,5 +1,6 @@
 # Create your views here.
 from django.conf import settings
+from django.core.exceptions import PermissionDenied
 from django.core.urlresolvers import reverse
 from django.http import Http404, HttpResponseRedirect
 from django.shortcuts import get_object_or_404
@@ -30,7 +31,7 @@ class NewPaymentView(FormView):
         return HttpResponseRedirect(gateway_url)
 
     def form_invalid(self, form):
-        raise Http404
+        raise PermissionDenied
 
 
 
